import { Component, OnInit, Input, Output } from "@angular/core";
import { SessionCartService } from "./session-cart.service";
import { Session } from "src/app/models/Session";
import { ActiveEventService } from 'src/app/services/active-event.service';

@Component({
    selector: "app-session-cart",
    templateUrl: "./session-cart.component.html",
    styleUrls: ["./session-cart.component.scss"]
})
export class SessionCartComponent implements OnInit {
    @Input()
    public readableEventId: string;

    public isSessionCartVisible: boolean;

    /**
     * All session IDs that are inside the session cart.
     */
    public sessionIdsInCart: Array<string>;

    public sessionsCart: Array<Session>;

    constructor(
        private sessionCartService: SessionCartService,
        private activeEventService: ActiveEventService) {}

    ngOnInit() {
        this.getSessionCart();

        this.subscribeToIsSessionCartOpen();
    }

    public collapse() {
        this.sessionCartService.isOpen = false;
    }

    public removeSessionFromCart(session: Session) {
        this.sessionCartService.removeSession(this.readableEventId, session.id);
    }

    public sessionCartCount(): number {
        return this.sessionIdsInCart.length;
    }

    private getSessionCart(): void {
        this.sessionIdsInCart = this.sessionCartService.getSessionCartForEvent(this.readableEventId);
        this.getSessionsWithId(this.sessionIdsInCart);

        this.sessionCartService.sessionCartChange.subscribe(sessionCart => {
            this.sessionIdsInCart = sessionCart;
            this.getSessionsWithId(this.sessionIdsInCart);
        });
    }

    private async getSessionsWithId(sessionIds: string[]) {
        this.sessionsCart = await this.activeEventService.getAndFilterSessions(this.readableEventId, true, sessionIds).toPromise();
    }

    private subscribeToIsSessionCartOpen(): void {
        this.isSessionCartVisible = this.sessionCartService.isOpen;
        this.sessionCartService.isOpenChange.subscribe(isOpen => {
            this.isSessionCartVisible = isOpen;
        });
    }
}
